@@ -26,67 +26,76 @@ import javax.inject.Inject;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.FunctionDefinition;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.FunctionDefinition;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
+import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.BaseEditorDefinition;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinitions;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionType;
-import org.kie.workbench.common.dmn.client.editors.expressions.types.function.parameters.ParametersEditorView;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.kindselector.KindPopoverView;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.parameters.ParametersPopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
-import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridData;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.ExpressionEditorChanged;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
-import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
-import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.DomainObjectSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
+import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
+import org.uberfire.ext.wires.core.grids.client.model.GridData;
 
 @ApplicationScoped
 public class FunctionEditorDefinition extends BaseEditorDefinition<FunctionDefinition, DMNGridData> {
 
     private Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
     private Supplier<ExpressionEditorDefinitions> supplementaryEditorDefinitionsSupplier;
-    private ParametersEditorView.Presenter parametersEditor;
+
+    private NameAndDataTypePopoverView.Presenter headerEditor;
+    private ParametersPopoverView.Presenter parametersEditor;
+    private KindPopoverView.Presenter kindEditor;
 
     public FunctionEditorDefinition() {
         //CDI proxy
     }
 
     @Inject
-    public FunctionEditorDefinition(final @DMNEditor DMNGridPanel gridPanel,
-                                    final @DMNEditor DMNGridLayer gridLayer,
-                                    final DefinitionUtils definitionUtils,
+    public FunctionEditorDefinition(final DefinitionUtils definitionUtils,
                                     final SessionManager sessionManager,
                                     final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
-                                    final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
+                                    final @DMNEditor DefaultCanvasCommandFactory canvasCommandFactory,
                                     final Event<ExpressionEditorChanged> editorSelectedEvent,
-                                    final CellEditorControlsView.Presenter cellEditorControls,
+                                    final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
+                                    final Event<DomainObjectSelectionEvent> domainObjectSelectionEvent,
                                     final ListSelectorView.Presenter listSelector,
                                     final TranslationService translationService,
                                     final @DMNEditor Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
                                     final @FunctionGridSupplementaryEditor Supplier<ExpressionEditorDefinitions> supplementaryEditorDefinitionsSupplier,
-                                    final ParametersEditorView.Presenter parametersEditor) {
-        super(gridPanel,
-              gridLayer,
-              definitionUtils,
+                                    final NameAndDataTypePopoverView.Presenter headerEditor,
+                                    final ParametersPopoverView.Presenter parametersEditor,
+                                    final KindPopoverView.Presenter kindEditor) {
+        super(definitionUtils,
               sessionManager,
               sessionCommandManager,
               canvasCommandFactory,
               editorSelectedEvent,
-              cellEditorControls,
+              refreshFormPropertiesEvent,
+              domainObjectSelectionEvent,
               listSelector,
               translationService);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
         this.supplementaryEditorDefinitionsSupplier = supplementaryEditorDefinitionsSupplier;
+        this.headerEditor = headerEditor;
         this.parametersEditor = parametersEditor;
+        this.kindEditor = kindEditor;
     }
 
     @Override
@@ -106,6 +115,7 @@ public class FunctionEditorDefinition extends BaseEditorDefinition<FunctionDefin
 
     @Override
     public void enrich(final Optional<String> nodeUUID,
+                       final HasExpression hasExpression,
                        final Optional<FunctionDefinition> expression) {
         expression.ifPresent(function -> {
             KindUtilities.setKind(function,
@@ -117,36 +127,40 @@ public class FunctionEditorDefinition extends BaseEditorDefinition<FunctionDefin
     }
 
     @Override
-    public Optional<BaseExpressionGrid> getEditor(final GridCellTuple parent,
-                                                  final Optional<String> nodeUUID,
-                                                  final HasExpression hasExpression,
-                                                  final Optional<FunctionDefinition> expression,
-                                                  final Optional<HasName> hasName,
-                                                  final int nesting) {
+    public Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>> getEditor(final GridCellTuple parent,
+                                                                                                                         final Optional<String> nodeUUID,
+                                                                                                                         final HasExpression hasExpression,
+                                                                                                                         final Optional<HasName> hasName,
+                                                                                                                         final boolean isOnlyVisualChangeAllowed,
+                                                                                                                         final int nesting) {
         return Optional.of(new FunctionGrid(parent,
                                             nodeUUID,
                                             hasExpression,
-                                            expression,
                                             hasName,
-                                            gridPanel,
-                                            gridLayer,
-                                            makeGridData(expression),
+                                            getGridPanel(),
+                                            getGridLayer(),
+                                            makeGridData(() -> Optional.ofNullable(((FunctionDefinition) hasExpression.getExpression()))),
                                             definitionUtils,
                                             sessionManager,
                                             sessionCommandManager,
                                             canvasCommandFactory,
                                             editorSelectedEvent,
-                                            cellEditorControls,
+                                            refreshFormPropertiesEvent,
+                                            domainObjectSelectionEvent,
+                                            getCellEditorControls(),
                                             listSelector,
                                             translationService,
+                                            isOnlyVisualChangeAllowed,
                                             nesting,
                                             expressionEditorDefinitionsSupplier,
                                             supplementaryEditorDefinitionsSupplier,
-                                            parametersEditor));
+                                            headerEditor,
+                                            parametersEditor,
+                                            kindEditor));
     }
 
     @Override
-    protected DMNGridData makeGridData(final Optional<FunctionDefinition> expression) {
+    protected DMNGridData makeGridData(final Supplier<Optional<FunctionDefinition>> expression) {
         return new DMNGridData();
     }
 }
