@@ -19,8 +19,9 @@ package org.kie.workbench.common.dmn.client.editors.expressions.types.undefined;
 import java.util.Optional;
 import java.util.function.Supplier;
 
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.context.ExpressionCellValue;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.BaseUIModelMapper;
@@ -30,16 +31,18 @@ import org.uberfire.ext.wires.core.grids.client.model.GridData;
 public class UndefinedExpressionUIModelMapper extends BaseUIModelMapper<Expression> {
 
     private final ListSelectorView.Presenter listSelector;
-
+    private final TranslationService translationService;
     private final HasExpression hasExpression;
 
     public UndefinedExpressionUIModelMapper(final Supplier<GridData> uiModel,
                                             final Supplier<Optional<Expression>> dmnModel,
                                             final ListSelectorView.Presenter listSelector,
+                                            final TranslationService translationService,
                                             final HasExpression hasExpression) {
         super(uiModel,
               dmnModel);
         this.listSelector = listSelector;
+        this.translationService = translationService;
         this.hasExpression = hasExpression;
     }
 
@@ -48,17 +51,19 @@ public class UndefinedExpressionUIModelMapper extends BaseUIModelMapper<Expressi
                              final int columnIndex) {
         uiModel.get().setCell(rowIndex,
                               columnIndex,
-                              () -> new UndefinedExpressionCell(listSelector));
+                              () -> new UndefinedExpressionCell(listSelector, translationService));
     }
 
     @Override
-    @SuppressWarnings("unchecked")
     public void toDMNModel(final int rowIndex,
                            final int columnIndex,
                            final Supplier<Optional<GridCellValue<?>>> cell) {
         cell.get().ifPresent(v -> {
             final ExpressionCellValue ecv = (ExpressionCellValue) v;
-            ecv.getValue().ifPresent(beg -> hasExpression.setExpression((Expression) beg.getExpression().orElse(null)));
+            ecv.getValue().ifPresent(beg -> {
+                hasExpression.setExpression(beg.getExpression().get().orElse(null));
+                beg.getExpression().get().ifPresent(e -> e.setParent(hasExpression.asDMNModelInstrumentedBase()));
+            });
         });
     }
 }
