@@ -16,30 +16,45 @@
 
 package org.kie.workbench.common.forms.editor.backend.service.impl;
 
-import javax.enterprise.event.Event;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.util.Arrays;
+import java.util.List;
 
+import javax.enterprise.event.Event;
+import javax.enterprise.inject.Instance;
+
+import org.apache.commons.io.IOUtils;
 import org.guvnor.common.services.backend.util.CommentedOptionFactory;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.forms.data.modeller.model.DataObjectFormModel;
+import org.kie.workbench.common.forms.dynamic.service.shared.RenderMode;
 import org.kie.workbench.common.forms.editor.model.FormModelerContent;
+import org.kie.workbench.common.forms.editor.service.backend.FormModelHandler;
 import org.kie.workbench.common.forms.editor.service.backend.FormModelHandlerManager;
-import org.kie.workbench.common.forms.editor.service.shared.VFSFormFinderService;
+import org.kie.workbench.common.forms.editor.service.backend.SourceFormModelNotFoundException;
+import org.kie.workbench.common.forms.editor.service.shared.ModuleFormFinderService;
 import org.kie.workbench.common.forms.editor.type.FormResourceTypeDefinition;
 import org.kie.workbench.common.forms.fields.test.TestFieldManager;
+import org.kie.workbench.common.forms.fields.test.TestMetaDataEntryManager;
 import org.kie.workbench.common.forms.model.FormDefinition;
 import org.kie.workbench.common.forms.model.FormModel;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
 import org.kie.workbench.common.forms.services.backend.serialization.FormDefinitionSerializer;
+import org.kie.workbench.common.forms.services.backend.serialization.impl.FieldSerializer;
+import org.kie.workbench.common.forms.services.backend.serialization.impl.FormDefinitionSerializerImpl;
+import org.kie.workbench.common.forms.services.backend.serialization.impl.FormModelSerializer;
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.Mock;
 import org.mockito.invocation.InvocationOnMock;
 import org.mockito.runners.MockitoJUnitRunner;
-import org.mockito.verification.VerificationMode;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.ext.editor.commons.service.CopyService;
 import org.uberfire.ext.editor.commons.service.DeleteService;
 import org.uberfire.ext.editor.commons.service.RenameService;
 import org.uberfire.io.IOService;
@@ -47,14 +62,17 @@ import org.uberfire.java.nio.file.FileAlreadyExistsException;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.workbench.events.ResourceOpenedEvent;
 
+import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -76,6 +94,9 @@ public class FormEditorServiceImplTest {
 
     private static final String COMMIT_COMMENT = "a comment";
 
+    @Mock
+    private Overview overview;
+
     @Mock
     private Path path;
 
@@ -91,19 +112,20 @@ public class FormEditorServiceImplTest {
     private FieldManager fieldManager = new TestFieldManager();
 
     @Mock
+    private FormModelHandler dataObjectFormModelHandler;
+
     private FormModelHandlerManager modelHandlerManager;
 
     @Mock
-    KieModuleService moduleService;
+    private KieModuleService moduleService;
 
     @Mock
     private KieModule module;
 
-    @Mock
     private FormDefinitionSerializer formDefinitionSerializer;
 
     @Mock
-    private VFSFormFinderService vfsFormFinderService;
+    private ModuleFormFinderService moduleFormFinderService;
 
     @Mock
     private DeleteService deleteService;
@@ -111,6 +133,9 @@ public class FormEditorServiceImplTest {
     @Mock
     private RenameService renameService;
 
+    @Mock
+    private CopyService copyService;
+
     @Mock
     private CommentedOptionFactory commentedOptionFactory;
 
@@ -118,6 +143,22 @@ public class FormEditorServiceImplTest {
 
     @Before
     public void init() {
+
+        Instance<FormModelHandler<? extends FormModel>> instances = mock(Instance.class);
+
+        when(dataObjectFormModelHandler.getModelType()).thenReturn(DataObjectFormModel.class);
+        when(dataObjectFormModelHandler.newInstance()).thenReturn(dataObjectFormModelHandler);
+
+        List<FormModelHandler> handlers = Arrays.asList(dataObjectFormModelHandler);
+
+        when(instances.iterator()).then(invocationOnMock -> handlers.iterator());
+
+        modelHandlerManager = spy(new FormModelHandlerManagerImpl(instances));
+
+        formDefinitionSerializer = spy(new FormDefinitionSerializerImpl(new FieldSerializer(),
+                                                                        new FormModelSerializer(),
+                                                                        new TestMetaDataEntryManager()));
+
         formEditorService = spy(new FormEditorServiceImpl(ioService,
                                                           sessionInfo,
                                                           resourceOpenedEvent,
@@ -125,10 +166,11 @@ public class FormEditorServiceImplTest {
                                                           modelHandlerManager,
                                                           moduleService,
                                                           formDefinitionSerializer,
-                                                          vfsFormFinderService,
+                                                          moduleFormFinderService,
                                                           deleteService,
                                                           commentedOptionFactory,
-                                                          renameService));
+                                                          renameService,
+                                                          copyService));
 
         when(path.toURI()).thenReturn("default:///src/main/resources/test.frm");
         when(moduleService.resolveModule(any())).thenReturn(module);
@@ -211,16 +253,99 @@ public class FormEditorServiceImplTest {
     private void testRename(boolean saveBeforeRenaming) {
         FormModelerContent content = mock(FormModelerContent.class);
         doReturn(path).when(formEditorService).save(any(Path.class), any(FormModelerContent.class), any(Metadata.class), anyString());
-        doReturn(content).when(formEditorService).constructContent(any(Path.class), any(Overview.class));
+
         when(content.getDefinition()).thenReturn(mock(FormDefinition.class));
         Metadata metadata = mock(Metadata.class);
 
         FormModelerContent resultContent = formEditorService.rename(path, NEW_FORM_NAME, COMMIT_COMMENT, saveBeforeRenaming, content, metadata);
 
         assertSame(content, resultContent);
-        VerificationMode constructContentCalls = saveBeforeRenaming ? never() : times(1);
-        verify(formEditorService, constructContentCalls).constructContent(eq(path), any(Overview.class));
-        verify(formEditorService).save(eq(path), eq(content), eq(metadata), eq(COMMIT_COMMENT));
+        verify(formEditorService, saveBeforeRenaming ? times(1) : never()).save(eq(path), eq(content), eq(metadata), eq(COMMIT_COMMENT));
         verify(renameService).rename(eq(path), eq(NEW_FORM_NAME), eq(COMMIT_COMMENT));
     }
+
+    @Test
+    public void testCopyAndSave() {
+        testCopy(true);
+    }
+
+    @Test
+    public void testCopyWithoutSaving() {
+        testCopy(false);
+    }
+
+    private void testCopy(boolean saveBeforeCopy) {
+        FormModelerContent content = mock(FormModelerContent.class);
+        doReturn(path).when(formEditorService).save(any(Path.class), any(FormModelerContent.class), any(Metadata.class), anyString());
+
+        when(content.getDefinition()).thenReturn(mock(FormDefinition.class));
+        Metadata metadata = mock(Metadata.class);
+
+        formEditorService.copy(path, NEW_FORM_NAME, COMMIT_COMMENT, saveBeforeCopy, content, metadata);
+
+        verify(formEditorService, saveBeforeCopy ? times(1) : never()).save(eq(path), eq(content), eq(metadata), eq(COMMIT_COMMENT));
+        verify(copyService).copy(eq(path), eq(NEW_FORM_NAME), eq(COMMIT_COMMENT));
+    }
+
+    @Test
+    public void testConstructContent() throws IOException, SourceFormModelNotFoundException {
+        String formContent = IOUtils.toString(new InputStreamReader(this.getClass().getResourceAsStream("test.frm")));
+
+        when(ioService.readAllString(any())).thenReturn(formContent);
+
+        FormModelerContent content = formEditorService.constructContent(path, overview);
+
+        verify(modelHandlerManager).getFormModelHandler(any());
+
+        verify(dataObjectFormModelHandler).init(any(), any());
+        verify(dataObjectFormModelHandler).checkSourceModel();
+        verify(dataObjectFormModelHandler).synchronizeFormModel();
+
+        verify(resourceOpenedEvent).fire(any());
+
+        assertNotNull(content);
+        assertNull(content.getError());
+        assertEquals(RenderMode.READ_ONLY_MODE, content.getRenderingContext().getRenderMode());
+    }
+
+    @Test
+    public void testConstructContentWithCheckModelFailure() throws IOException, SourceFormModelNotFoundException {
+        SourceFormModelNotFoundException exception = new SourceFormModelNotFoundException("exception", null, "exception", null, "model", null);
+
+        doThrow(exception)
+                .when(dataObjectFormModelHandler).checkSourceModel();
+
+        String formContent = IOUtils.toString(new InputStreamReader(this.getClass().getResourceAsStream("test.frm")));
+
+        when(ioService.readAllString(any())).thenReturn(formContent);
+
+        FormModelerContent content = formEditorService.constructContent(path, overview);
+
+        verify(modelHandlerManager).getFormModelHandler(any());
+
+        verify(dataObjectFormModelHandler).init(any(), any());
+        verify(dataObjectFormModelHandler).checkSourceModel();
+        verify(dataObjectFormModelHandler, never()).synchronizeFormModel();
+
+        verify(resourceOpenedEvent).fire(any());
+
+        assertNotNull(content);
+        assertNotNull(content.getError());
+        assertEquals(exception.getShortKey(), content.getError().getShortKey());
+        assertArrayEquals(exception.getShortKeyParams(), content.getError().getShortKeyParams());
+        assertEquals(exception.getLongKey(), content.getError().getLongKey());
+        assertArrayEquals(exception.getLongKeyParams(), content.getError().getLongKeyParams());
+    }
+
+    @Test
+    public void testConstructContentWithUnexpectedFailure() {
+
+        FormModelerContent content = formEditorService.constructContent(path, overview);
+
+        verify(modelHandlerManager, never()).getFormModelHandler(any());
+        verify(resourceOpenedEvent).fire(any());
+
+        assertNotNull(content);
+        assertNotNull(content.getError());
+    }
 }
