@@ -19,7 +19,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.assertj.core.api.Assertions;
 import org.eclipse.bpmn2.Definitions;
+import org.jbpm.bpmn2.handler.WorkItemHandlerRuntimeException;
 import org.jbpm.simulation.util.BPMN2Utils;
 import org.junit.Before;
 import org.junit.BeforeClass;
@@ -56,6 +58,7 @@ public class BPMNFormModelGeneratorImplTest {
             BPMN2_SUFFIX = ".bpmn2",
             PROCESS_WITHOUT_VARIABLES_NAME = "process-without-variables",
             PROCESS_WITH_ALL_VARIABLES_NAME = "process-with-all-possible-variables",
+            PROCESS_WITH_WRONG_TYPES = "process-with-wrong-types",
             PROCESS_WITH_SHARED_FORMS_NAME = "process-with-tasks-sharing-forms",
             PROCESS_WITH_SHARED_FORMS_WRONG_MAPPINGS_NAME = "process-with-tasks-sharing-forms-with-wrong-mapping",
             PROCESS_WITH_SHARED_FORMS_ID = "myProject.processTaskSharedForms",
@@ -79,6 +82,8 @@ public class BPMNFormModelGeneratorImplTest {
             DATA_OBJECT_TYPE);
         put("_customType",
             CUSTOM_TYPE);
+        put("_list",
+            Object.class.getName());
     }};
 
     private static final Map<String, String> EXPECTED_OUTPUT_VARIABLES = new HashMap<String, String>() {{
@@ -96,13 +101,16 @@ public class BPMNFormModelGeneratorImplTest {
             DATA_OBJECT_TYPE);
         put("customType_",
             CUSTOM_TYPE);
+        put("list_",
+            Object.class.getName());
     }};
     private static BPMNFormModelGeneratorImpl generator;
     private static Definitions
             processWithoutVariablesDefinitions,
             processWithAllVariablesDefinitions,
             processWithSharedForms,
-            processWithSharedFormsWrongMappings;
+            processWithSharedFormsWrongMappings,
+            processWithWrongTypes;
     @Mock
     private Path path;
     @Mock
@@ -120,10 +128,11 @@ public class BPMNFormModelGeneratorImplTest {
         processWithAllVariablesDefinitions = BPMN2Utils.getDefinitions(BPMNFormModelGeneratorImplTest.class.getResourceAsStream(RESOURCES_PATH + PROCESS_WITH_ALL_VARIABLES_NAME + BPMN2_SUFFIX));
         processWithSharedForms = BPMN2Utils.getDefinitions(BPMNFormModelGeneratorImplTest.class.getResourceAsStream(RESOURCES_PATH + PROCESS_WITH_SHARED_FORMS_NAME + BPMN2_SUFFIX));
         processWithSharedFormsWrongMappings = BPMN2Utils.getDefinitions(BPMNFormModelGeneratorImplTest.class.getResourceAsStream(RESOURCES_PATH + PROCESS_WITH_SHARED_FORMS_WRONG_MAPPINGS_NAME + BPMN2_SUFFIX));
+        processWithWrongTypes  = BPMN2Utils.getDefinitions(BPMNFormModelGeneratorImplTest.class.getResourceAsStream(RESOURCES_PATH + PROCESS_WITH_WRONG_TYPES + BPMN2_SUFFIX));
     }
 
     @Before
-    public void init() throws ClassNotFoundException {
+    public void init() throws Exception {
         when(projectService.resolveModule(any())).thenReturn(module);
         when(module.getRootPath()).thenReturn(path);
         when(projectClassLoaderHelper.getModuleClassLoader(module)).thenReturn(projectClassLoader);
@@ -164,6 +173,7 @@ public class BPMNFormModelGeneratorImplTest {
                 DATA_OBJECT_TYPE);
             put("customType",
                 CUSTOM_TYPE);
+            put("list", Object.class.getName());
         }};
 
         //generate all = generateProcessFormModel + generateTaskFormModels
@@ -221,21 +231,16 @@ public class BPMNFormModelGeneratorImplTest {
     public void testCorrectTaskFormModelIsGeneratedForTaskWithTheInputsAndOutputsBoundToTheSameNamesInSwimlane() {
         final String TASK_ID = "_9903B013-C42D-486B-A41D-2DEBC60911E3",
                 TASK_NAME = "taskWithTheSameInputsAndOutputs";
+
         final Map<String, String> EXPECTED_TASK_VARIABLES = new HashMap<String, String>() {{
-            put("_string_",
-                String.class.getName());
-            put("_integer_",
-                Integer.class.getName());
-            put("_boolean_",
-                Boolean.class.getName());
-            put("_float_",
-                Float.class.getName());
-            put("_object_",
-                Object.class.getName());
-            put("_dataObject_",
-                DATA_OBJECT_TYPE);
-            put("_customType_",
-                CUSTOM_TYPE);
+            put("_string_", String.class.getName());
+            put("_integer_", Integer.class.getName());
+            put("_boolean_", Boolean.class.getName());
+            put("_float_", Float.class.getName());
+            put("_object_", Object.class.getName());
+            put("_dataObject_", DATA_OBJECT_TYPE);
+            put("_customType_", CUSTOM_TYPE);
+            put("_list_", Object.class.getName());
         }};
 
         TaskFormModel taskFormModel = generator.generateTaskFormModel(processWithAllVariablesDefinitions,
@@ -371,6 +376,48 @@ public class BPMNFormModelGeneratorImplTest {
         }
     }
 
+    @Test
+    public void testGenerateAllWithWrongTypes() throws Exception {
+        when(projectClassLoader.loadClass(anyString())).thenAnswer(invocationOnMock -> getClass().getClassLoader().loadClass(invocationOnMock.getArguments()[0].toString()));
+
+        final Map<String, String> EXPECTED_PROPERTIES = new HashMap<String, String>() {{
+            put("name", String.class.getName());
+            put("age", Integer.class.getName());
+            put("error", WorkItemHandlerRuntimeException.class.getName());
+            put("list", Object.class.getName());
+        }};
+
+        BusinessProcessFormModel processFormModel = generator.generateProcessFormModel(processWithWrongTypes, path);
+
+        assertProcessFormModelFieldsAreCorrect(processFormModel, PROCESS_WITH_WRONG_TYPES);
+
+        Assertions.assertThat(processFormModel.getProperties())
+                .isNotNull()
+                .isNotEmpty()
+                .hasSize(EXPECTED_PROPERTIES.size());
+
+        assertEquals(EXPECTED_PROPERTIES.size(), processFormModel.getProperties().size());
+        assertJBPMVariablesAreCorrect(processFormModel, EXPECTED_PROPERTIES);
+
+        List<TaskFormModel> taskFormModels = generator.generateTaskFormModels(processWithWrongTypes,
+                                                                              path);
+        final int EXPECTED_NUMBER_OF_HUMAN_TASKS = 1;
+
+        Assertions.assertThat(taskFormModels)
+                .isNotNull()
+                .isNotEmpty()
+                .hasSize(EXPECTED_NUMBER_OF_HUMAN_TASKS);
+
+        TaskFormModel taskFormModel = taskFormModels.get(0);
+
+        Assertions.assertThat(taskFormModel.getProperties())
+                .isNotNull()
+                .isNotEmpty()
+                .hasSize(EXPECTED_PROPERTIES.size());
+
+        assertJBPMVariablesAreCorrect(taskFormModel, EXPECTED_PROPERTIES);
+    }
+
     protected void checkExpectedMergedFormVariables(TaskFormModel formModel) {
         final Map<String, String> EXPECTED_TYPES = new HashMap<>();
         EXPECTED_TYPES.put("name",
@@ -404,11 +451,9 @@ public class BPMNFormModelGeneratorImplTest {
                                                Map<String, String> expectedVariables) {
         Map<String, String> actualVariables = new HashMap<>();
         for (ModelProperty modelProperty : formModel.getProperties()) {
-            actualVariables.put(modelProperty.getName(),
-                                modelProperty.getTypeInfo().getClassName());
+            actualVariables.put(modelProperty.getName(), modelProperty.getTypeInfo().getClassName());
         }
-        assertEquals(expectedVariables,
-                     actualVariables);
+        assertEquals(expectedVariables, actualVariables);
     }
 
     private void assertTaskFormModelIsCorrect(TaskFormModel taskFormModel,
