@@ -16,14 +16,17 @@
 
 package org.kie.workbench.common.screens.projecteditor.backend.server;
 
+import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Optional;
 
 import org.guvnor.common.services.backend.util.CommentedOptionFactory;
+import org.guvnor.common.services.project.backend.server.WorkspaceProjectServiceImpl;
 import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.MavenRepositoryMetadata;
 import org.guvnor.common.services.project.model.MavenRepositorySource;
+import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.ModuleRepositories;
 import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.ProjectImports;
@@ -33,7 +36,6 @@ import org.guvnor.common.services.project.service.GAVAlreadyExistsException;
 import org.guvnor.common.services.project.service.ModuleRepositoriesService;
 import org.guvnor.common.services.project.service.ModuleRepositoryResolver;
 import org.guvnor.common.services.project.service.POMService;
-import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
@@ -41,7 +43,7 @@ import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryCopier;
 import org.guvnor.structure.repositories.RepositoryService;
-import org.jboss.errai.security.shared.api.identity.User;
+import org.guvnor.structure.repositories.impl.git.GitRepository;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -54,7 +56,6 @@ import org.kie.workbench.common.services.shared.kmodule.KModuleService;
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.services.shared.project.ProjectImportsService;
-import org.kie.workbench.common.services.shared.validation.ValidationService;
 import org.kie.workbench.common.services.shared.whitelist.PackageNameWhiteListService;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
@@ -64,9 +65,9 @@ import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.base.options.CommentedOption;
 import org.uberfire.java.nio.file.FileSystem;
-import org.uberfire.rpc.SessionInfo;
 import org.uberfire.spaces.Space;
 
+import static java.util.Collections.emptyList;
 import static org.junit.Assert.*;
 import static org.mockito.Mockito.*;
 
@@ -79,9 +80,6 @@ public class ProjectScreenServiceImplTest {
     @Mock
     private KieModuleService moduleService;
 
-    @Mock
-    private ValidationService validationService;
-
     @Mock
     private ProjectImportsService importsService;
 
@@ -94,12 +92,6 @@ public class ProjectScreenServiceImplTest {
     @Mock
     private ModuleRepositoryResolver repositoryResolver;
 
-    @Mock
-    private User identity;
-
-    @Mock
-    private SessionInfo sessionInfo;
-
     @Mock
     private IOService ioService;
 
@@ -149,7 +141,7 @@ public class ProjectScreenServiceImplTest {
     private MetadataService metadataService;
 
     @Mock
-    private WorkspaceProjectService projectService;
+    private WorkspaceProjectServiceImpl projectService;
 
     private ProjectScreenService service;
     private ProjectScreenModelLoader loader;
@@ -186,7 +178,8 @@ public class ProjectScreenServiceImplTest {
                                               kModuleService,
                                               importsService,
                                               repositoriesService,
-                                              whiteListService) {
+                                              whiteListService,
+                                              projectService) {
             @Override
             protected boolean fileExists(final Path path) {
                 return true;
@@ -228,6 +221,14 @@ public class ProjectScreenServiceImplTest {
         when(metadataService.getMetadata(eq(pathToPom))).thenReturn(pomMetaData);
         when(metadataService.getMetadata(eq(pathToKieModule))).thenReturn(kmoduleMetaData);
         when(metadataService.getMetadata(eq(pathToModuleImports))).thenReturn(projectImportsMetaData);
+
+        when(projectService.resolveProject((Path) any()))
+                .thenReturn(spy(new WorkspaceProject(mock(OrganizationalUnit.class),
+                                                     new GitRepository("alias",
+                                                                       mock(Space.class),
+                                                                       emptyList()),
+                                                     mock(Branch.class),
+                                                     mock(Module.class))));
     }
 
     @Test
@@ -260,6 +261,9 @@ public class ProjectScreenServiceImplTest {
         assertEquals(pathToModuleRepositories,
                      model.getPathToRepositories());
 
+        assertEquals(emptyList(),
+                     model.getGitUrls());
+
         verify(pomService,
                times(1)).load(eq(pathToPom));
         verify(metadataService,
@@ -767,6 +771,13 @@ public class ProjectScreenServiceImplTest {
 
     @Test
     public void testCopy() throws Exception {
+
+        when(projectService.createFreshProjectName(any(),
+                                                   any())).thenCallRealMethod();
+        doReturn(Arrays.asList(mock(WorkspaceProject.class))).when(projectService).getAllWorkspaceProjectsByName(any(),
+                                                                                                                 eq("newName"),
+                                                                                                                 anyBoolean());
+
         final WorkspaceProject project = mock(WorkspaceProject.class);
         final OrganizationalUnit ou = mock(OrganizationalUnit.class);
         final Path projectRoot = mock(Path.class);
@@ -774,7 +785,8 @@ public class ProjectScreenServiceImplTest {
         doReturn(projectRoot).when(project).getRootPath();
 
         final Repository newRepository = mock(Repository.class);
-        final Path newRepositoryRoot = PathFactory.newPath("root", "file:///root");
+        final Path newRepositoryRoot = PathFactory.newPath("root",
+                                                           "file:///root");
         doReturn(Optional.of(new Branch("master",
                                         newRepositoryRoot))).when(newRepository).getDefaultBranch();
 
@@ -800,8 +812,10 @@ public class ProjectScreenServiceImplTest {
                                 eq(true));
 
         final POM updatedPom = pomArgumentCaptor.getValue();
-        assertEquals("newName", updatedPom.getName());
-        assertEquals("newName", updatedPom.getGav().getArtifactId());
+        assertEquals("newName-1",
+                     updatedPom.getName());
+        assertEquals("newName",
+                     updatedPom.getGav().getArtifactId());
     }
 
     @Test
@@ -813,9 +827,11 @@ public class ProjectScreenServiceImplTest {
         doReturn(projectRoot).when(project).getRootPath();
 
         final Repository newRepository = mock(Repository.class);
-        final Path newRepositoryRoot = PathFactory.newPath("root", "file:///root");
+        final Path newRepositoryRoot = PathFactory.newPath("root",
+                                                           "file:///root");
 
-        doReturn(Optional.of(new Branch("master", newRepositoryRoot))).when(newRepository).getDefaultBranch();
+        doReturn(Optional.of(new Branch("master",
+                                        newRepositoryRoot))).when(newRepository).getDefaultBranch();
 
         doReturn(newRepository).when(repositoryCopier).copy(ou,
                                                             "newName",
@@ -830,12 +846,14 @@ public class ProjectScreenServiceImplTest {
                                       "newName",
                                       projectRoot);
 
-        verify(metadataService, never()).getMetadata(any(Path.class));
-        verify(pomService, never()).save(any(Path.class),
-                                         any(POM.class),
-                                         any(Metadata.class),
-                                         anyString(),
-                                         anyBoolean());
+        verify(metadataService,
+               never()).getMetadata(any(Path.class));
+        verify(pomService,
+               never()).save(any(Path.class),
+                             any(POM.class),
+                             any(Metadata.class),
+                             anyString(),
+                             anyBoolean());
     }
 
     @Test
@@ -858,6 +876,7 @@ public class ProjectScreenServiceImplTest {
 
         service.delete(project);
 
-        verify(repositoryService).removeRepository(eq(space), eq("myrepo"));
+        verify(repositoryService).removeRepository(eq(space),
+                                                   eq("myrepo"));
     }
 }
\ No newline at end of file
