@@ -20,18 +20,14 @@ import java.util.Collection;
 
 import org.jboss.errai.bus.server.annotations.Remote;
 import org.kie.server.controller.api.model.runtime.Container;
-import org.kie.server.controller.api.model.runtime.ServerInstanceKey;
 import org.kie.workbench.common.screens.server.management.model.ContainerSpecData;
 
 @Remote
 public interface RuntimeManagementService {
 
-    Collection<ServerInstanceKey> getServerInstances( final String serverTemplateId );
-
-    Collection<Container> getContainersByServerInstance( final String serverTemplateId,
-                                                         final String serverInstanceId );
-
-    ContainerSpecData getContainersByContainerSpec( final String serverTemplateId,
-                                                    final String containerSpecId );
+    Collection<Container> getContainersByServerInstance(String serverTemplateId,
+                                                        String serverInstanceId);
 
+    ContainerSpecData getContainersByContainerSpec(String serverTemplateId,
+                                                   String containerSpecId);
 }
