@@ -23,7 +23,11 @@ import org.kie.workbench.common.screens.datamodeller.security.DataModelerFeature
  */
 public interface WorkbenchFeatures extends DataModelerFeatures {
 
-    String PLANNER_AVAILABLE = "planner.available";
-
     String EDIT_GLOBAL_PREFERENCES = "globalpreferences.edit";
-}
\ No newline at end of file
+
+    String GUIDED_DECISION_TABLE_EDIT_COLUMNS = "guideddecisiontable.edit.columns";
+
+    String EDIT_PROFILE_PREFERENCES = "profilepreferences.edit";
+
+    String ACCESS_DATA_TRANSFER = "datatransfer.access";
+}
