@@ -162,6 +162,7 @@ public interface DefaultWorkbenchConstants
     String ScenarioSimulationEditor();
 
     String ExperimentalSettings();
+
     String ProcessAdministration();
 
     String TestReport();
@@ -171,4 +172,10 @@ public interface DefaultWorkbenchConstants
     String EditProfilePreferencesHelp();
 
     String ServiceTasksAdministration();
+
+    String DataTransfer();
+
+    String AccessDataTransfer();
+
+    String AccessDataTransferHelp();
 }
