@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,18 +18,20 @@ package org.kie.workbench.common.stunner.core.graph.content.view;
 
 import java.util.Optional;
 
+import org.kie.workbench.common.stunner.core.graph.content.HasControlPoints;
+
 /**
  * Indicates that the view for the node/edge represents a physical connector that will the drawn in the canvas.
  * @param <W> The Definition of the connector's graphical view representation.
  */
-public interface ViewConnector<W> extends View<W> {
+public interface ViewConnector<W> extends View<W>,
+                                          HasControlPoints {
 
-    Optional<Magnet> getSourceMagnet();
+    Optional<Connection> getSourceConnection();
 
-    Optional<Magnet> getTargetMagnet();
+    Optional<Connection> getTargetConnection();
 
-    void setSourceMagnet(final Magnet magnet);
-
-    void setTargetMagnet(final Magnet magnet);
+    void setSourceConnection(final Connection connection);
 
+    void setTargetConnection(final Connection connection);
 }
