@@ -26,6 +26,7 @@ import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHand
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramFocusEvent;
 import org.kie.workbench.common.stunner.project.client.editor.event.OnDiagramLoseFocusEvent;
 import org.kie.workbench.common.stunner.project.client.screens.ProjectMessagesListener;
@@ -43,6 +44,7 @@ class ProjectDiagramEditorStub extends AbstractProjectDiagramEditor<ClientResour
     static final String EDITOR_ID = "ProjectDiagramEditorStub";
 
     public ProjectDiagramEditorStub(final View view,
+                                    final DocumentationView documentationView,
                                     final PlaceManager placeManager,
                                     final ErrorPopupPresenter errorPopupPresenter,
                                     final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
@@ -60,6 +62,7 @@ class ProjectDiagramEditorStub extends AbstractProjectDiagramEditor<ClientResour
                                     final TextEditorView xmlEditorView,
                                     final Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller) {
         super(view,
+              documentationView,
               placeManager,
               errorPopupPresenter,
               changeTitleNotificationEvent,
@@ -78,16 +81,6 @@ class ProjectDiagramEditorStub extends AbstractProjectDiagramEditor<ClientResour
               projectDiagramResourceServiceCaller);
     }
 
-    @Override
-    protected int getCanvasWidth() {
-        return 100;
-    }
-
-    @Override
-    protected int getCanvasHeight() {
-        return 100;
-    }
-
     @Override
     protected String getEditorIdentifier() {
         return EDITOR_ID;
