@@ -21,9 +21,9 @@ import java.util.Objects;
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
@@ -37,24 +37,27 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.variables.Proce
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanContain;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@CanContain(roles = {"cm_activity", "cm_stage", "IntermediateEventsMorph", "GatewaysMorph"})
+@CanContain(roles = {"cm_activity", "cm_stage", "IntermediateEventsMorph", "GatewaysMorph", "EndEventsMorph", "text_annotation", "connector"})
 @CanDock(roles = {"IntermediateEventOnSubprocessBoundary"})
-@Definition(graphFactory = NodeFactory.class, builder = AdHocSubprocess.AdHocSubprocessBuilder.class)
+@Definition(graphFactory = NodeFactory.class)
 @Morph(base = BaseSubprocess.class)
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class AdHocSubprocess
-        extends BaseSubprocess {
+        extends BaseAdHocSubprocess<ProcessData, AdHocSubprocessTaskExecutionSet> {
 
     @PropertySet
     @FormField(afterElement = "general")
@@ -66,22 +69,18 @@ public class AdHocSubprocess
     @Valid
     private ProcessData processData;
 
-    @NonPortable
-    public static class AdHocSubprocessBuilder implements Builder<AdHocSubprocess> {
-
-        @Override
-        public AdHocSubprocess build() {
-            return new AdHocSubprocess(new BPMNGeneralSet("Sub-process"),
-                                       new BackgroundSet(),
-                                       new FontSet(),
-                                       new RectangleDimensionsSet(),
-                                       new SimulationSet(),
-                                       new AdHocSubprocessTaskExecutionSet(),
-                                       new ProcessData());
-        }
+    public AdHocSubprocess() {
+        this("Sub-process");
     }
 
-    public AdHocSubprocess() {
+    public AdHocSubprocess(String label) {
+        this(new BPMNGeneralSet(label),
+             new BackgroundSet(),
+             new FontSet(),
+             new RectangleDimensionsSet(),
+             new SimulationSet(),
+             new AdHocSubprocessTaskExecutionSet(),
+             new ProcessData());
     }
 
     public AdHocSubprocess(final @MapsTo("general") BPMNGeneralSet general,
@@ -100,18 +99,22 @@ public class AdHocSubprocess
         this.processData = processData;
     }
 
+    @Override
     public AdHocSubprocessTaskExecutionSet getExecutionSet() {
         return executionSet;
     }
 
+    @Override
     public void setExecutionSet(final AdHocSubprocessTaskExecutionSet executionSet) {
         this.executionSet = executionSet;
     }
 
+    @Override
     public ProcessData getProcessData() {
         return processData;
     }
 
+    @Override
     public void setProcessData(final ProcessData processData) {
         this.processData = processData;
     }
@@ -128,10 +131,8 @@ public class AdHocSubprocess
         if (o instanceof AdHocSubprocess) {
             AdHocSubprocess other = (AdHocSubprocess) o;
             return super.equals(other) &&
-                    Objects.equals(executionSet,
-                                   other.executionSet) &&
-                    Objects.equals(processData,
-                                   other.processData);
+                    Objects.equals(executionSet, other.executionSet) &&
+                    Objects.equals(processData, other.processData);
         }
         return false;
     }
