@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.bpmn.definition.property.dataio;
 
+import java.util.Objects;
+
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
@@ -23,13 +25,10 @@ import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldLabel;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNPropertySet;
 import org.kie.workbench.common.stunner.bpmn.forms.model.AssignmentsEditorFieldType;
-import org.kie.workbench.common.stunner.core.definition.annotation.Name;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
-import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @Portable
 @Bindable
@@ -39,10 +38,6 @@ import org.kie.workbench.common.stunner.core.util.HashUtil;
 )
 public class DataIOSet implements BPMNPropertySet {
 
-    @Name
-    @FieldLabel
-    public static final transient String propertySetName = "Task Data";
-
     @Property
     @FormField(
             type = AssignmentsEditorFieldType.class
@@ -62,10 +57,6 @@ public class DataIOSet implements BPMNPropertySet {
         this.assignmentsinfo = new AssignmentsInfo(assignmentsinfo);
     }
 
-    public String getPropertySetName() {
-        return propertySetName;
-    }
-
     public AssignmentsInfo getAssignmentsinfo() {
         return assignmentsinfo;
     }
@@ -76,7 +67,7 @@ public class DataIOSet implements BPMNPropertySet {
 
     @Override
     public int hashCode() {
-        return assignmentsinfo.hashCode();
+        return Objects.hash(getAssignmentsinfo());
     }
 
     @Override
