@@ -19,17 +19,10 @@ package org.kie.workbench.common.stunner.bpmn.definition.property.font;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldDefinition;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldLabel;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldReadOnly;
 import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.FieldValue;
-import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.LabelMode;
+import org.kie.workbench.common.forms.adf.definitions.annotations.metaModel.I18nMode;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNProperty;
-import org.kie.workbench.common.stunner.core.definition.annotation.Description;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
-import org.kie.workbench.common.stunner.core.definition.annotation.property.Caption;
-import org.kie.workbench.common.stunner.core.definition.annotation.property.DefaultValue;
-import org.kie.workbench.common.stunner.core.definition.annotation.property.Optional;
-import org.kie.workbench.common.stunner.core.definition.annotation.property.ReadOnly;
 import org.kie.workbench.common.stunner.core.definition.annotation.property.Type;
 import org.kie.workbench.common.stunner.core.definition.annotation.property.Value;
 import org.kie.workbench.common.stunner.core.definition.property.PropertyType;
@@ -38,32 +31,15 @@ import org.kie.workbench.common.stunner.core.definition.property.type.ColorType;
 @Portable
 @Bindable
 @Property
-@FieldDefinition(labelMode = LabelMode.OVERRIDE_I18N_KEY)
+@FieldDefinition(i18nMode = I18nMode.OVERRIDE_I18N_KEY)
 public class FontColor implements BPMNProperty {
 
-    @Caption
-    @FieldLabel
-    public static final transient String caption = "Font Color";
-
-    @Description
-    public static final transient String description = "The Font Color";
-
-    @ReadOnly
-    @FieldReadOnly
-    private Boolean readOnly = false;
-
-    @Optional
-    public static final Boolean optional = false;
-
     @Type
     public static final PropertyType type = new ColorType();
 
-    @DefaultValue
-    public static final transient String defaultValue = "#000000";
-
     @Value
     @FieldValue
-    private String value = defaultValue;
+    private String value;
 
     public FontColor() {
     }
@@ -72,30 +48,10 @@ public class FontColor implements BPMNProperty {
         this.value = value;
     }
 
-    public String getCaption() {
-        return caption;
-    }
-
-    public String getDescription() {
-        return description;
-    }
-
-    public boolean isReadOnly() {
-        return readOnly;
-    }
-
-    public boolean isOptional() {
-        return optional;
-    }
-
     public PropertyType getType() {
         return type;
     }
 
-    public String getDefaultValue() {
-        return defaultValue;
-    }
-
     public String getValue() {
         return value;
     }
