@@ -28,14 +28,15 @@ import org.kie.workbench.common.stunner.bpmn.definition.BaseSubprocess;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseTask;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseThrowingIntermediateEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.Lane;
+import org.kie.workbench.common.stunner.bpmn.definition.TextAnnotation;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
 public class FlowElementConverter {
 
-    private final BaseConverterFactory converterFactory;
+    private final ConverterFactory converterFactory;
 
-    public FlowElementConverter(BaseConverterFactory converterFactory) {
+    public FlowElementConverter(ConverterFactory converterFactory) {
         this.converterFactory = converterFactory;
     }
 
@@ -48,6 +49,7 @@ public class FlowElementConverter {
                 .when(BaseTask.class, converterFactory.taskConverter()::toFlowElement)
                 .when(BaseGateway.class, converterFactory.gatewayConverter()::toFlowElement)
                 .when(BaseReusableSubprocess.class, converterFactory.reusableSubprocessConverter()::toFlowElement)
+                .when(TextAnnotation.class, converterFactory.textAnnotationConverter()::toElement)
                 .ignore(BaseSubprocess.class)
                 .ignore(Lane.class)
                 .apply(node);
