@@ -61,7 +61,8 @@ public class TaskConverter {
                 .when(BaseUserTask.class, this::userTask)
                 .when(ServiceTask.class, this::serviceTask)
                 .when(GenericServiceTask.class, this::genericServiceTask)
-                .apply(node).value();
+                .apply(node)
+                .value();
     }
 
     private PropertyWriter genericServiceTask(Node<View<GenericServiceTask>, ?> n) {
@@ -89,6 +90,20 @@ public class TaskConverter {
         p.setServiceOperation(executionSet.getGenericServiceTaskInfo()
                                       .getValue()
                                       .getServiceOperation());
+        p.setAsync(executionSet.getIsAsync().getValue());
+        p.setAdHocAutostart(executionSet.getAdHocAutostart().getValue());
+        if (Boolean.TRUE.equals(executionSet.getIsMultipleInstance().getValue())) {
+            p.setIsSequential(executionSet.getMultipleInstanceExecutionMode().isSequential());
+            p.setCollectionInput(executionSet.getMultipleInstanceCollectionInput().getValue());
+            p.setInput(executionSet.getMultipleInstanceDataInput().getValue());
+            p.setCollectionOutput(executionSet.getMultipleInstanceCollectionOutput().getValue());
+            p.setOutput(executionSet.getMultipleInstanceDataOutput().getValue());
+            p.setCompletionCondition(executionSet.getMultipleInstanceCompletionCondition().getValue());
+        }
+        p.setOnEntryAction(executionSet.getOnEntryAction());
+        p.setOnExitAction(executionSet.getOnExitAction());
+        p.setSLADueDate(executionSet.getSlaDueDate().getValue());
+        p.setAssignmentsInfo(executionSet.getAssignmentsinfo());
         return p;
     }
 
@@ -116,6 +131,7 @@ public class TaskConverter {
         p.setOnEntryAction(executionSet.getOnEntryAction());
         p.setOnExitAction(executionSet.getOnExitAction());
         p.setAdHocAutostart(executionSet.getAdHocAutostart().getValue());
+        p.setSlaDueDate(executionSet.getSlaDueDate().getValue());
 
         p.setSimulationSet(definition.getSimulationSet());
 
@@ -185,6 +201,7 @@ public class TaskConverter {
         p.setOnEntryAction(executionSet.getOnEntryAction());
         p.setOnExitAction(executionSet.getOnExitAction());
         p.setAdHocAutostart(executionSet.getAdHocAutostart().getValue());
+        p.setSlaDueDate(executionSet.getSlaDueDate().getValue());
 
         RuleLanguage ruleLanguage = executionSet.getRuleLanguage();
         p.setImplementation(ruleLanguage);
