@@ -26,9 +26,7 @@ import org.eclipse.bpmn2.DataInput;
 import org.eclipse.bpmn2.DataInputAssociation;
 import org.eclipse.bpmn2.DataOutput;
 import org.eclipse.bpmn2.DataOutputAssociation;
-import org.eclipse.bpmn2.Property;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.AssociationDeclaration;
-import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.AssociationDeclaration.Direction;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.AssociationList;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.CustomAttribute;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.DeclarationList;
@@ -37,7 +35,6 @@ import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.AssignmentsInfo;
 
 import static java.util.Arrays.asList;
-import static org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.AssociationDeclaration.Type;
 
 public class AssignmentsInfos {
 
@@ -66,6 +63,22 @@ public class AssignmentsInfos {
             final List<DataOutputAssociation> outputAssociations,
             boolean alternativeEncoding) {
 
+        ParsedAssignmentsInfo parsedAssignmentsInfo = parsed(
+                datainput,
+                inputAssociations,
+                dataoutput,
+                outputAssociations,
+                alternativeEncoding);
+
+        return new AssignmentsInfo(parsedAssignmentsInfo.toString());
+    }
+
+    public static ParsedAssignmentsInfo parsed(
+            List<DataInput> datainput,
+            List<DataInputAssociation> inputAssociations,
+            List<DataOutput> dataoutput,
+            List<DataOutputAssociation> outputAssociations,
+            boolean alternativeEncoding) {
         DeclarationList inputs = dataInputDeclarations(datainput);
         DeclarationList outputs = dataOutputDeclarations(dataoutput);
 
@@ -73,8 +86,8 @@ public class AssignmentsInfos {
                 inAssociationDeclarations(inputAssociations),
                 outAssociationDeclarations(outputAssociations));
 
-        return new AssignmentsInfo(new ParsedAssignmentsInfo(
-                inputs, outputs, associations, alternativeEncoding).toString());
+        return new ParsedAssignmentsInfo(
+                inputs, outputs, associations, alternativeEncoding);
     }
 
     public static boolean isReservedDeclaration(DataInput o) {
@@ -95,10 +108,9 @@ public class AssignmentsInfos {
                         .collect(Collectors.toList()));
     }
 
-    private static DeclarationList dataOutputDeclarations(List<DataOutput> dataInputs) {
+    private static DeclarationList dataOutputDeclarations(List<DataOutput> dataOutputs) {
         return new DeclarationList(
-                dataInputs.stream()
-                        .filter(o -> !CustomAttribute.dtype.of(o).get().isEmpty())
+                dataOutputs.stream()
                         .map(out -> new VariableDeclaration(
                                 out.getName(),
                                 CustomAttribute.dtype.of(out).get()))
@@ -115,17 +127,11 @@ public class AssignmentsInfos {
     }
 
     private static List<AssociationDeclaration> outAssociationDeclarations(List<DataOutputAssociation> outputAssociations) {
-        return outputAssociations.stream()
-                .map(out -> new AssociationDeclaration(
-                        Direction.Output,
-                        Type.SourceTarget,
-                        ((DataOutput) out.getSourceRef().get(0)).getName(),
-                        getPropertyName((Property) out.getTargetRef())))
+        return outputAssociations
+                .stream()
+                .map(OutputAssignmentReader::fromAssociation)
+                .filter(Objects::nonNull)
+                .map(OutputAssignmentReader::getAssociationDeclaration)
                 .collect(Collectors.toList());
     }
-
-    // fallback to ID for https://issues.jboss.org/browse/JBPM-6708
-    private static String getPropertyName(Property prop) {
-        return prop.getName() == null ? prop.getId() : prop.getName();
-    }
-}
+}
\ No newline at end of file
