@@ -17,7 +17,6 @@
 package org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.events.intermediate;
 
 import org.junit.Test;
-import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.Marshaller;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.CancellingErrorEventExecutionSet;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -27,7 +26,7 @@ import org.kie.workbench.common.stunner.core.graph.Graph;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
-public class BoundaryCatchingIntermediateErrorEventTest extends BoundaryCatchingIntermediateEvent<IntermediateErrorEventCatching> {
+public class BoundaryCatchingIntermediateErrorEventTest extends BoundaryCatchingIntermediateEventTest<IntermediateErrorEventCatching> {
 
     private static final String BPMN_CATCHING_INTERMEDIATE_EVENT_FILE_PATH = "org/kie/workbench/common/stunner/bpmn/backend/service/diagram/boundaryErrorEvents.bpmn";
 
@@ -45,10 +44,6 @@ public class BoundaryCatchingIntermediateErrorEventTest extends BoundaryCatching
 
     private static final int AMOUNT_OF_NODES_IN_DIAGRAM = 31;
 
-    public BoundaryCatchingIntermediateErrorEventTest(Marshaller marshallerType) {
-        super(marshallerType);
-    }
-
     @Test
     @Override
     public void testUnmarshallTopLevelEventFilledProperties() throws Exception {
