@@ -100,7 +100,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVA,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskJava.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledTopLevelTaskJavascript = getTaskNodeById(getDiagram(),
@@ -114,7 +115,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVASCRIPT,
                                       TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskJavascript.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledTopLevelTaskMvel = getTaskNodeById(getDiagram(),
@@ -128,7 +130,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_MVEL,
                                       TASK_SCRIPT_MVEL_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskMvel.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -149,7 +152,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       EMPTY_VALUE,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_NOT_ASYNC,
-                                      NOT_AD_HOC_AUTOSTART);
+                                      NOT_AD_HOC_AUTOSTART,
+                                      EMPTY_VALUE);
         assertDataIOSet(emptyTopLevelTask.getDataIOSet(), EMPTY_TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -186,7 +190,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVA,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskJava.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledSubprocessLevelTaskJavascript = getTaskNodeById(getDiagram(),
@@ -200,7 +205,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVASCRIPT,
                                       TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskJavascript.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledSubprocessLevelTaskMvel = getTaskNodeById(getDiagram(),
@@ -214,7 +220,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_MVEL,
                                       TASK_SCRIPT_MVEL_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskMvel.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -234,7 +241,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       EMPTY_VALUE,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_NOT_ASYNC,
-                                      NOT_AD_HOC_AUTOSTART);
+                                      NOT_AD_HOC_AUTOSTART,
+                                      EMPTY_VALUE);
         assertDataIOSet(emptySubprocessLevelTask.getDataIOSet(), EMPTY_TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -271,7 +279,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVA,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskJava.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledTopLevelTaskJavascript = getTaskNodeById(getDiagram(),
@@ -285,7 +294,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVASCRIPT,
                                       TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskJavascript.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledTopLevelTaskMvel = getTaskNodeById(getDiagram(),
@@ -299,7 +309,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_MVEL,
                                       TASK_SCRIPT_MVEL_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskMvel.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -319,7 +330,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       EMPTY_VALUE,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_NOT_ASYNC,
-                                      NOT_AD_HOC_AUTOSTART);
+                                      NOT_AD_HOC_AUTOSTART,
+                                      EMPTY_VALUE);
         assertDataIOSet(emptyTopLevelTask.getDataIOSet(), EMPTY_TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -339,7 +351,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       EMPTY_VALUE,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_NOT_ASYNC,
-                                      NOT_AD_HOC_AUTOSTART);
+                                      NOT_AD_HOC_AUTOSTART,
+                                      EMPTY_VALUE);
         assertDataIOSet(emptySubprocessLevelTask.getDataIOSet(), EMPTY_TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -376,7 +389,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVA,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskJava.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledSubprocessLevelTaskJavascript = getTaskNodeById(getDiagram(),
@@ -390,7 +404,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVASCRIPT,
                                       TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskJavascript.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledSubprocessLevelTaskMvel = getTaskNodeById(getDiagram(),
@@ -404,7 +419,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_MVEL,
                                       TASK_SCRIPT_MVEL_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskMvel.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -441,7 +457,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVA,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskJava.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledTopLevelTaskJavascript = getTaskNodeById(getDiagram(),
@@ -455,7 +472,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVASCRIPT,
                                       TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskJavascript.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledTopLevelTaskMvel = getTaskNodeById(getDiagram(),
@@ -469,7 +487,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_MVEL,
                                       TASK_SCRIPT_MVEL_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledTopLevelTaskMvel.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -489,7 +508,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       EMPTY_VALUE,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_NOT_ASYNC,
-                                      NOT_AD_HOC_AUTOSTART);
+                                      NOT_AD_HOC_AUTOSTART,
+                                      EMPTY_VALUE);
         assertDataIOSet(emptyTopLevelTask.getDataIOSet(), EMPTY_TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -509,7 +529,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       EMPTY_VALUE,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_NOT_ASYNC,
-                                      NOT_AD_HOC_AUTOSTART);
+                                      NOT_AD_HOC_AUTOSTART,
+                                      EMPTY_VALUE);
         assertDataIOSet(emptySubprocessLevelTask.getDataIOSet(), EMPTY_TASK_DATA_INPUT_OUTPUT);
     }
 
@@ -546,7 +567,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVA,
                                       TASK_SCRIPT_JAVA_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskJava.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledSubprocessLevelTaskJavascript = getTaskNodeById(getDiagram(),
@@ -560,7 +582,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_JAVASCRIPT,
                                       TASK_SCRIPT_JAVASCRIPT_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskJavascript.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
 
         ServiceTask filledSubprocessLevelTaskMvel = getTaskNodeById(getDiagram(),
@@ -574,7 +597,8 @@ public class RestServiceTaskTest extends BaseServiceTaskTest<ServiceTask> {
                                       TASK_ON_EXIT_ACTION_MVEL,
                                       TASK_SCRIPT_MVEL_LANGUAGE,
                                       IS_ASYNC,
-                                      AD_HOC_AUTOSTART);
+                                      AD_HOC_AUTOSTART,
+                                      SLA_DUE_DATE);
         assertDataIOSet(filledSubprocessLevelTaskMvel.getDataIOSet(), TASK_DATA_INPUT_OUTPUT);
     }
 
