@@ -34,8 +34,6 @@ public interface VariableListItemWidgetView extends HasModel<VariableRow> {
 
     void setDataTypes(final ListBoxValues dataTypeListBoxValues);
 
-    boolean isDuplicateName(final String name);
-
     VariableType getVariableType();
 
     String getDataTypeDisplayName();
@@ -45,4 +43,8 @@ public interface VariableListItemWidgetView extends HasModel<VariableRow> {
     String getCustomDataType();
 
     void setCustomDataType(final String customDataType);
+
+    void setReadOnly(final boolean readOnly);
+
+    void setKPINotEnabled();
 }
