@@ -22,6 +22,7 @@ import java.util.List;
 
 import javax.enterprise.event.Event;
 
+import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.dom.client.TableCellElement;
 import com.google.gwt.event.dom.client.ClickEvent;
@@ -38,7 +39,6 @@ import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.VariableR
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.workbench.events.NotificationEvent;
 
@@ -54,7 +54,7 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(LienzoMockitoTestRunner.class)
 public class VariablesEditorWidgetViewImplTest {
 
     protected static final String VARIABLES = "employee:java.lang.String,reason:java.lang.String,performance:java.lang.String";
@@ -90,6 +90,9 @@ public class VariablesEditorWidgetViewImplTest {
     @GwtMock
     private ListWidget<VariableRow, VariableListItemWidgetViewImpl> variableRows;
 
+    @GwtMock
+    private TableCellElement kpith;
+
     private VariablesEditorWidgetViewImpl view;
 
     @Captor
@@ -111,6 +114,7 @@ public class VariablesEditorWidgetViewImplTest {
         view.nameth = nameth;
         view.datatypeth = datatypeth;
         view.notification = notification;
+        view.kpith = kpith;
         doCallRealMethod().when(view).setVariableRows(any(List.class));
         doCallRealMethod().when(view).init(any(VariablesEditorWidgetView.Presenter.class));
         doCallRealMethod().when(view).handleAddVarButton(any(ClickEvent.class));
@@ -124,6 +128,7 @@ public class VariablesEditorWidgetViewImplTest {
                                                  anyBoolean());
         doCallRealMethod().when(view).setDataTypes(anyListOf(String.class),
                                                    anyListOf(String.class));
+        doCallRealMethod().when(view).setReadOnly(anyBoolean());
         rows = new ArrayList<VariableRow>();
         rows.add(new VariableRow(Variable.VariableType.PROCESS,
                                  "varName",
@@ -211,4 +216,26 @@ public class VariablesEditorWidgetViewImplTest {
         verify(view,
                times(1)).initView();
     }
+
+    @Test
+    public void testSetReadOnlyTrue() {
+        view.setReadOnly(true);
+        verify(button,
+               times(1)).setEnabled(false);
+        for (int i = 0; i < variableRows.getValue().size(); i++) {
+            verify(view.getVariableWidget(i),
+                   times(1)).setReadOnly(true);
+        }
+    }
+
+    @Test
+    public void testSetReadOnlyFalse() {
+        view.setReadOnly(false);
+        verify(button,
+               times(1)).setEnabled(true);
+        for (int i = 0; i < variableRows.getValue().size(); i++) {
+            verify(view.getVariableWidget(i),
+                   times(1)).setReadOnly(false);
+        }
+    }
 }
